@@ -33,6 +33,10 @@ class PermissionConf(AppConf):
     DEFAULT_GIPL_CHANGE_PERMISSION = True
     DEFAULT_GIPL_DELETE_PERMISSION = False
 
+    DEFAULT_OSPL_ANY_PERMISSION = False
+    DEFAULT_OSPL_CHANGE_PERMISSION = True
+    DEFAULT_OSPL_DELETE_PERMISSION = True
+
     DEFAULT_SPL_ANY_PERMISSION = False
     DEFAULT_SPL_ADD_PERMISSION = True
     DEFAULT_SPL_CHANGE_PERMISSION = True
